%% @file
% calcu3.m
%
% @author Lars Johannesen
%
% @section DISCLAIMER
% This software and documentation (the "Software") were developed at the Food  
% and Drug Administration (FDA) by employees of the Federal Government in the  
% course of their official duties. Pursuant to Title 17, Section 105 of the    
% United States Code, this work is not subject to copyright protection and is  
% in the public domain. Permission is hereby granted, free of charge, to any   
% person obtaining a copy of the Software, to deal in the Software without     
% restriction, including without limitation the rights to use, copy, modify,   
% merge, publish, distribute, sublicense, or sell copies of the Software or    
% derivatives, and to permit persons to whom the Software is furnished to do   
% so. FDA assumes no responsibility whatsoever for use by other parties of     
% the Software, its source code, documentation or compiled executables, and    
% makes no guarantees, expressed or implied, about its quality, reliability,   
%  or any other characteristic. Further, use of this code in no way implies    
% endorsement by the FDA or confers any advantage in regulatory decisions.     
% Although this software can be redistributed and/or modified freely, we       
% ask that any derivative works bear some notice that they are derived from    
% it, and any modified versions bear some notice that they have been modified. 
% @section Examples:
%  u3 = calcu3(ecg, 100, 2);
%
% @section See also:
% qrsdetect

%%
% @brief Calculates the u3 for each lead of the ECG for a qrswidth (samples) with ith or smoothing factor (samples). The default used in the paper is 100 for qrswidth and 2 for smoothing parameter.
% @param ecg ECG matrix
% @param fs Sampling frequency
% @param qrswidth Width of U3 window
% @param ith Smooting factor
% @return u3 Matrix with U3 for each ECG lead
%
function [u3] = calcu3(ecg, fs, qrswidth, ith)
%calcu3 Calcs the U3 for each lead
%
% calcu3(ECG, qrswidth, ith)
%
% ECG - matrix
% fs  - sampling freq
% qrswidth - width of U3 window
% ith  - smoothing factor
%
% Calculates the u3 for each lead of the ECG for a qrswidth (samples) with
% ith or smoothing factor (samples).
%
% The default used in the paper is 100 for qrswidth and 2 for smoothing 
% parameter.
%
%                                  DISCLAIMER                                  
% This software and documentation (the "Software") were developed at the Food  
% and Drug Administration (FDA) by employees of the Federal Government in the  
% course of their official duties. Pursuant to Title 17, Section 105 of the    
% United States Code, this work is not subject to copyright protection and is  
% in the public domain. Permission is hereby granted, free of charge, to any   
% person obtaining a copy of the Software, to deal in the Software without     
% restriction, including without limitation the rights to use, copy, modify,   
% merge, publish, distribute, sublicense, or sell copies of the Software or    
% derivatives, and to permit persons to whom the Software is furnished to do   
% so. FDA assumes no responsibility whatsoever for use by other parties of     
% the Software, its source code, documentation or compiled executables, and    
% makes no guarantees, expressed or implied, about its quality, reliability,   
%  or any other characteristic. Further, use of this code in no way implies    
% endorsement by the FDA or confers any advantage in regulatory decisions.     
% Although this software can be redistributed and/or modified freely, we       
% ask that any derivative works bear some notice that they are derived from    
% it, and any modified versions bear some notice that they have been modified. 
%                                                                              
% Written by: Lars Johannesen
%
% Examples:
%  u3 = calcu3(ecg, 100, 2);
%
% See also:
% qrsdetect
