%% @file
% search_dictionary.m
%
% @author Jose Vicente
%
% @section DISCLAIMER
% This software and documentation (the "Software") were developed at the Food  
% and Drug Administration (FDA) by employees of the Federal Government in the  
% course of their official duties. Pursuant to Title 17, Section 105 of the    
% United States Code, this work is not subject to copyright protection and is  
% in the public domain. Permission is hereby granted, free of charge, to any   
% person obtaining a copy of the Software, to deal in the Software without     
% restriction, including without limitation the rights to use, copy, modify,   
% merge, publish, distribute, sublicense, or sell copies of the Software or    
% derivatives, and to permit persons to whom the Software is furnished to do   
% so. FDA assumes no responsibility whatsoever for use by other parties of     
% the Software, its source code, documentation or compiled executables, and    
% makes no guarantees, expressed or implied, about its quality, reliability,   
%  or any other characteristic. Further, use of this code in no way implies    
% endorsement by the FDA or confers any advantage in regulatory decisions.     
% Although this software can be redistributed and/or modified freely, we       
% ask that any derivative works bear some notice that they are derived from    
% it, and any modified versions bear some notice that they have been modified. 
%
% 
% @section See also:
% word_distance

%%
% @brief Returns the closest word from a dictionary using the levenshtein's distance function
% @param word Word to search for
% @param dictionary cell array of the known strings in the dictionary
% @return closer_word - best match, index of match, success (true/false) and distance

function [closer_word, idx, success, dist] = search_dictionary(word,dictionary)
%search_dictionary Returns the closest word from a dictionary using the levenshtein's distance function
%
% word	string with the word to search for
%
% dictionary	cell array of the known strings in the dictionary
%
%                                  DISCLAIMER                                  
% This software and documentation (the "Software") were developed at the Food  
% and Drug Administration (FDA) by employees of the Federal Government in the  
% course of their official duties. Pursuant to Title 17, Section 105 of the    
% United States Code, this work is not subject to copyright protection and is  
% in the public domain. Permission is hereby granted, free of charge, to any   
% person obtaining a copy of the Software, to deal in the Software without     
% restriction, including without limitation the rights to use, copy, modify,   
% merge, publish, distribute, sublicense, or sell copies of the Software or    
% derivatives, and to permit persons to whom the Software is furnished to do   
% so. FDA assumes no responsibility whatsoever for use by other parties of     
% the Software, its source code, documentation or compiled executables, and    
% makes no guarantees, expressed or implied, about its quality, reliability,   
%  or any other characteristic. Further, use of this code in no way implies    
% endorsement by the FDA or confers any advantage in regulatory decisions.     
% Although this software can be redistributed and/or modified freely, we       
% ask that any derivative works bear some notice that they are derived from    
% it, and any modified versions bear some notice that they have been modified. 
%                                                                              
% Written by: Jose Vicente
	success = false;
	closer_word = '';
	idx = -1;

	parts = strsplit(word, ' ');
	if length(parts) > 1
		word2search = parts{1};
	else
		word2search = word;
	end

	distances = zeros(1,length(dictionary));
	for i=1:length(distances)
		distances(i)=word_distance(word2search,dictionary{i});
	end

	[dist, loc] = min(distances);
	if (dist>0)
		word2search = (strrep(word,' ','_'));
		distances = zeros(1,length(dictionary));
		for i=1:length(distances)
			distances(i)=word_distance(word2search,dictionary{i});
		end
		if (dist < 7)
			%Get first closer hit in the dictionary
			closer_word = dictionary{loc};
			idx = loc;
			success = true;
		end
	else
		%Full match on the first word
		closer_word = dictionary{loc};
		idx = loc;
		success = true;
	end
end
