%% @file
% word_distance.m
%
% @author Wikipedia
%
% @section DISCLAIMER
% This code is licensed under Creative Commons: Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0). See details at source's website: http://en.wikibooks.org/wiki/Algorithm_Implementation/Strings/Levenshtein_distance#Octave_And_MATLAB
% 
%

%%
% @brief returns the levensteihn's distance between the two strings
% @param string1 String1
% @param string2 String2
% @return dist distance, L distance matrix

function [dist,L]=word_distance(str1,str2)
% word_distance returns the levenshtein's distance between the two strings
%
% This file is licensed under Creative Commons: Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0). See details at source's website: http://en.wikibooks.org/wiki/Algorithm_Implementation/Strings/Levenshtein_distance#Octave_And_MATLAB
%
% 

	L1=length(str1)+1;
	L2=length(str2)+1;
	L=zeros(L1,L2);

	g=+1;%just constant
	m=+0;%match is cheaper, we seek to minimize
	d=+1;%not-a-match is more costly.

	%do BC's
	L(:,1)=([0:L1-1]*g)';
	L(1,:)=[0:L2-1]*g;

	m4=0;%loop invariant
	for idx=2:L1;
	for idy=2:L2
if(str1(idx-1)==str2(idy-1))
	score=m;
	else
	score=d;
	end
	m1=L(idx-1,idy-1) + score;
	m2=L(idx-1,idy) + g;
	m3=L(idx,idy-1) + g;
	L(idx,idy)=min(m1,min(m2,m3));
	end
	end

	dist=L(L1,L2);
	return
	end
